==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_az.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="az">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>مركز الإشعارات</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>إلغاء تثبيت</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>تثبيت</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>إعداد الإشعارات</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>الآن</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 دقيقة مضت</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 ساعة مضت</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>أمس </translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>مركز الإشعارات</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>إلغاء تثبيت</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>تثبيت</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>إعداد الإشعارات</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>الآن</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 دقيقة مضت</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 ساعة مضت</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>أمس </translation>
    </message>
</context>
</TS>
